@@ -88,8 +88,7 @@ Objective-C -> (\"objective-c\" . \"objc\")"
                                   (map-elt block 'body))
                                 source-blocks)))
     (markdown-overlays-remove)
-    (when markdown-overlays-highlight-blocks
-      (dolist (block source-blocks)
+    (dolist (block source-blocks)
         (markdown-overlays--fontify-source-block
          (car (map-elt block 'start))
          (cdr (map-elt block 'start))
@@ -100,7 +99,7 @@ Objective-C -> (\"objective-c\" . \"objc\")"
          (car (map-elt block 'body))
          (cdr (map-elt block 'body))
          (car (map-elt block 'end))
-         (cdr (map-elt block 'end)))))
+         (cdr (map-elt block 'end))))
     (when markdown-overlays-insert-dividers
       (dolist (divider (markdown-overlays--divider-markers))
         (markdown-overlays--fontify-divider (car divider) (cdr divider))))
@@ -252,7 +251,8 @@ Use QUOTES1-START QUOTES1-END LANG LANG-START LANG-END BODY-START
         (props)
         (overlay)
         (propertized-text))
-    (if (fboundp lang-mode)
+    (if (and markdown-overlays-highlight-blocks
+             (fboundp lang-mode))
         (progn
           (setq propertized-text
                 (with-current-buffer
